aboutsummaryrefslogtreecommitdiffstats
path: root/createRandomTest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'createRandomTest.cpp')
-rw-r--r--createRandomTest.cpp20
1 files changed, 14 insertions, 6 deletions
diff --git a/createRandomTest.cpp b/createRandomTest.cpp
index 1af12f64..b3a704e9 100644
--- a/createRandomTest.cpp
+++ b/createRandomTest.cpp
@@ -54,18 +54,26 @@ int main(int argc, char *argv[])
gen.seed(static_cast<unsigned int>(timeSinceEpoch));
boost::random::uniform_int_distribution<> lengthOfCodeDist(2, 16);
boost::random::uniform_int_distribution<> opcodeDist(0, 255);
+ boost::random::uniform_int_distribution<> BlockInfoOpcodeDist(0x40, 0x45);
boost::random::variate_generator<boost::mt19937&,
boost::random::uniform_int_distribution<> > randGen(gen, opcodeDist);
+ boost::random::variate_generator<boost::mt19937&,
+ boost::random::uniform_int_distribution<> > randGenBlockInfoOpcode(gen, BlockInfoOpcodeDist);
int lengthOfCode = lengthOfCodeDist(gen);
string randomCode;
for (int i = 0; i < lengthOfCode; ++i)
{
- uint8_t opcode = randGen();
+ if (i < 8 && (randGen() < 192))
+ {
+ randomCode += toHex(toCompactBigEndian((uint8_t)randGenBlockInfoOpcode()));
+ continue;
+ }
- // disregard all invalid commands, except of one (0x10)
- if (dev::eth::isValidInstruction(dev::eth::Instruction(opcode)) || opcode == 0x10)
+ uint8_t opcode = randGen();
+ // disregard all invalid commands, except of one (0x0c)
+ if ((dev::eth::isValidInstruction(dev::eth::Instruction(opcode)) || (opcode == 0x0c)))
randomCode += toHex(toCompactBigEndian(opcode));
else
i--;
@@ -78,8 +86,8 @@ int main(int argc, char *argv[])
\"previousHash\" : \"5e20a0453cecd065ea59c37ac63e079ee08998b6045136a8ce6635c7912ec0b6\",\n\
\"currentNumber\" : \"0\",\n\
\"currentGasLimit\" : \"1000000\",\n\
- \"currentDifficulty\" : \"256\",\n\
- \"currentTimestamp\" : 1,\n\
+ \"currentDifficulty\" : \"115792089237316195423570985008687907853269984665640564039457584007913129639935\",\n\
+ \"currentTimestamp\" : 2,\n\
\"currentCoinbase\" : \"2adc25665018aa1fe0e6bc666dac8fc2697ff9ba\"\n\
},\n\
\"pre\" : {\n\
@@ -106,7 +114,7 @@ int main(int argc, char *argv[])
read_string(s, v);
// insert new random code
- v.get_obj().find("randomVMtest")->second.get_obj().find("pre")->second.get_obj().begin()->second.get_obj()["code"] = "0x" + randomCode;
+ v.get_obj().find("randomVMtest")->second.get_obj().find("pre")->second.get_obj().begin()->second.get_obj()["code"] = "0x" + randomCode + "55";
// execute code in vm
doMyTests(v);